@@ -1,6 +1,6 @@
 package Resque;
 # ABSTRACT: Redis-backed library for creating background jobs, placing them on multiple queues, and processing them later.
-$Resque::VERSION = '0.39';
+$Resque::VERSION = '0.40';
 use Moose;
 use Scalar::Util 'blessed';
 use Moose::Util::TypeConstraints;
@@ -78,12 +78,12 @@ sub pop {
 
 sub blpop {
     my ( $self, $queues, $timeout ) = @_;
-    my ( $queue, $payload ) = $self->redis->blpop(( map { $self->key( queue => $_ ) } @$queues ), $timeout || 0 );
+    my ( $key, $payload ) = $self->redis->blpop(( map { $self->key( queue => $_ ) } @$queues ), $timeout || 0 );
     return unless $payload;
 
     $self->new_job({
         payload => $payload,
-        queue   => $queue
+        queue   => (split(':', $key))[-1]
     });
 }
 
@@ -201,7 +201,7 @@ Resque - Redis-backed library for creating background jobs, placing them on mult
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 SYNOPSIS
 
